@@ -18,27 +18,35 @@
  * 
  */
 
-#define XML_TOC_URL		"http://www.hinduismtoday.com/digital/htde_toc.xml"
-
-/* currently unused - see 0.1 patch-30 for latest version parsing media */
-#define MEDIA_TOC_URL	"http://www.hinduismtoday.com/digital/htde_media-player.rev.gz"
+#define XML_TOC_URI		"http://www.hinduismtoday.com/digital/htde_toc.xml"
 
 #define ISS_XML_FILE	"htde_toc.xml"
 
 #define STR_MAX		512
 
-typedef enum
-{
-	NONE,
-	HTTP,
-	SOCKS4,
-	SOCKS5
-} proxytype;
+#include <curl/curl.h>
 
-typedef enum
-{
-	NOAUTH,
-	BASIC,
-	DIGEST,
-	NTLM,
-} proxyauth;
+struct proxy_options {
+	char type;
+	char auth;
+	char address[STR_MAX];
+	long port;
+	char user[STR_MAX];
+	char pass[STR_MAX];
+};
+
+struct config {
+	char toc_xml[STR_MAX];
+	char issue_uri[STR_MAX];
+
+	char save_path[STR_MAX];
+
+	struct proxy_options proxy;
+
+	int startup_check;
+
+	int verbose;
+	int quiet;
+
+	CURL *curl_handle;
+};
